@@ -45,13 +45,13 @@ my_draw (GnomePrintContext *gpc)
 }
 
 static void
-my_set_names (GnomePrintJob *gpm)
+my_set_names (GnomePrintJob *job)
 {
 	GnomePrintConfig *config;
 	gchar *printer;
 	gchar *output_filename;
 	
-	config = gnome_print_job_get_config (gpm);
+	config = gnome_print_job_get_config (job);
 
 	/* Set the printer */
 	gnome_print_config_set (config, "Printer", "GENERIC");
@@ -72,12 +72,12 @@ my_set_names (GnomePrintJob *gpm)
 }
 
 static void
-my_dump_orientation (GnomePrintJob *gpm)
+my_dump_orientation (GnomePrintJob *job)
 {
 	GnomePrintConfig *config;
 	gchar *orientation;
 
-	config = gnome_print_job_get_config (gpm);
+	config = gnome_print_job_get_config (job);
 
 	orientation = gnome_print_config_get (config, GNOME_PRINT_KEY_ORIENTATION);
 	g_print ("Orientation is: %s\n", orientation);
@@ -88,19 +88,19 @@ my_dump_orientation (GnomePrintJob *gpm)
 static void
 my_print (void)
 {
-	GnomePrintJob *gpm;
+	GnomePrintJob *job;
 	GnomePrintContext *gpc;
 
-	gpm = gnome_print_job_new (NULL);
-	gpc = gnome_print_job_get_context (gpm);
+	job = gnome_print_job_new (NULL);
+	gpc = gnome_print_job_get_context (job);
 
-	my_set_names (gpm);
-	my_dump_orientation (gpm);
+	my_set_names (job);
+	my_dump_orientation (job);
 	
 	my_draw (gpc);
 
-	gnome_print_job_close (gpm);
-	gnome_print_job_print (gpm);
+	gnome_print_job_close (job);
+	gnome_print_job_print (job);
 }
 
 int
