@@ -50,16 +50,16 @@ static void
 my_print (void)
 {
 	GnomePrintContext *gpc;
-	GnomePrintJob *gpm;
+	GnomePrintJob *job;
 	GnomePrintConfig *config;
 	GtkWidget *dialog;
 	gint response;
 
 	/* Create the objects */
-	gpm    = gnome_print_job_new (NULL);
-	dialog = gnome_print_dialog_new (gpm, "Sample print dialog", 0);
-	gpc    = gnome_print_job_get_context (gpm);
-	config = gnome_print_job_get_config (gpm);
+	job    = gnome_print_job_new (NULL);
+	dialog = gnome_print_dialog_new (job, "Sample print dialog", 0);
+	gpc    = gnome_print_job_get_context (job);
+	config = gnome_print_job_get_config (job);
 
 	/* Run the dialog */
 	gtk_widget_show (dialog);
@@ -72,7 +72,7 @@ my_print (void)
 	/* Draw & print */
 	my_draw (gpc);
 	gnome_print_config_dump (config);
-	gnome_print_job_close (gpm);
+	gnome_print_job_close (job);
 
 	/* We don't print, we only dump the info */
 }
